<?php

namespace Assetdocs\Incident\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Incident\Http\Requests\IncidentreportingAdminWebRequest;
use Assetdocs\Incident\Interfaces\IncidentreportingRepositoryInterface;
use Assetdocs\Incident\Models\Incidentreporting;

/**
 * Admin web controller class.
 */
class IncidentreportingAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize incidentreporting controller.
     *
     * @param type IncidentreportingRepositoryInterface $incidentreporting
     *
     * @return type
     */
    public function __construct(IncidentreportingRepositoryInterface $incidentreporting)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $incidentreporting;
        parent::__construct();
    }

    /**
     * Display a list of incidentreporting.
     *
     * @return Response
     */
    public function index(IncidentreportingAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $incidentreportings  = $this->repository
            ->pushCriteria(new \Assetdocs\Incident\Repositories\Criteria\IncidentreportingAdminCriteria())
                ->setPresenter('\\Assetdocs\\Incident\\Repositories\\Presenter\\IncidentreportingListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $incidentreportings['recordsTotal']    = $incidentreportings['meta']['pagination']['total'];
            $incidentreportings['recordsFiltered'] = $incidentreportings['meta']['pagination']['total'];
            $incidentreportings['request']         = $request->all();
            return response()->json($incidentreportings, 200);

        }

        $this   ->theme->prependTitle(trans('incident::incidentreporting.names').' :: ');
        return $this->theme->of('incident::admin.incidentreporting.index')->render();
    }

    /**
     * Display incidentreporting.
     *
     * @param Request $request
     * @param Model   $incidentreporting
     *
     * @return Response
     */
    public function show(IncidentreportingAdminWebRequest $request, Incidentreporting $incidentreporting)
    {
        if (!$incidentreporting->exists) {
            return response()->view('incident::admin.incidentreporting.new', compact('incidentreporting'));
        }

        Form::populate($incidentreporting);
        return response()->view('incident::admin.incidentreporting.show', compact('incidentreporting'));
    }

    /**
     * Show the form for creating a new incidentreporting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(IncidentreportingAdminWebRequest $request)
    {

        $incidentreporting = $this->repository->newInstance([]);

        Form::populate($incidentreporting);

        return response()->view('incident::admin.incidentreporting.create', compact('incidentreporting'));

    }

    /**
     * Create new incidentreporting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(IncidentreportingAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $incidentreporting          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('incident::incidentreporting.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/incident/incidentreporting/'.$incidentreporting->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show incidentreporting for editing.
     *
     * @param Request $request
     * @param Model   $incidentreporting
     *
     * @return Response
     */
    public function edit(IncidentreportingAdminWebRequest $request, Incidentreporting $incidentreporting)
    {
        Form::populate($incidentreporting);
        return  response()->view('incident::admin.incidentreporting.edit', compact('incidentreporting'));
    }

    /**
     * Update the incidentreporting.
     *
     * @param Request $request
     * @param Model   $incidentreporting
     *
     * @return Response
     */
    public function update(IncidentreportingAdminWebRequest $request, Incidentreporting $incidentreporting)
    {
        try {

            $attributes = $request->all();

            $incidentreporting->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('incident::incidentreporting.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/incident/incidentreporting/'.$incidentreporting->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/incident/incidentreporting/'.$incidentreporting->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the incidentreporting.
     *
     * @param Model   $incidentreporting
     *
     * @return Response
     */
    public function destroy(IncidentreportingAdminWebRequest $request, Incidentreporting $incidentreporting)
    {

        try {

            $t = $incidentreporting->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('incident::incidentreporting.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/incident/incidentreporting/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/incident/incidentreporting/'.$incidentreporting->getRouteKey()),
            ], 400);
        }
    }
}
